@@ -1,11 +1,14 @@
+import json
 import unittest
 from io import StringIO
 from os import remove
 from os.path import exists, join
 from unittest.mock import Mock
 
+from dockerfile_parse import DockerfileParser
 from rich.progress import Progress, SpinnerColumn
 
+from q8s.constants import BASE_IMAGES, WORKSPACE
 from q8s.plugins.utils.git_info import GitInfo
 from q8s.project import Project
 
@@ -96,6 +99,148 @@ class TestProject(unittest.TestCase):
 
         project.clear_cache()
 
+    @unittest.mock.patch("q8s.project.datetime")
+    @unittest.mock.patch("q8s.project.load")
+    def test_create_dockerfile_cpu(self, mock_load: Mock, mock_datetime: Mock):
+        mock_load.return_value = mocked_configuration
+        mock_datetime.now.return_value.isoformat.return_value = "2024-01-01T00:00:00"
+
+        project = Project("tests/fixtures/cache")
+
+        dockerfile = StringIO()
+        project._Project__create_dockerfile("cpu", dockerfile)
+
+        dfp = DockerfileParser(fileobj=dockerfile)
+
+        lines = [line for line in dfp.content.splitlines()]
+
+        self.assertEqual(
+            lines,
+            [
+                "# This file is autogenerated by q8sctl",
+                "# Do not edit manually",
+                "",
+                f"FROM {BASE_IMAGES['cpu']}",
+                "",
+                "LABEL org.opencontainers.image.created=2024-01-01T00:00:00",
+                f"LABEL org.opencontainers.image.title={project.name}",
+                "",
+                f"WORKDIR {WORKSPACE}",
+                "COPY requirements.txt .",
+                "RUN pip install --no-cache -r requirements.txt",
+            ],
+        )
+
+    @unittest.mock.patch("q8s.project.datetime")
+    @unittest.mock.patch("q8s.project.load")
+    def test_create_dockerfile_gpu(self, mock_load: Mock, mock_datetime: Mock):
+        mock_load.return_value = mocked_configuration
+        mock_datetime.now.return_value.isoformat.return_value = "2024-01-01T00:00:00"
+
+        project = Project("tests/fixtures/cache")
+
+        dockerfile = StringIO()
+        project._Project__create_dockerfile("gpu", dockerfile)
+
+        dfp = DockerfileParser(fileobj=dockerfile)
+
+        lines = [line for line in dfp.content.splitlines()]
+
+        self.assertEqual(
+            lines,
+            [
+                "# This file is autogenerated by q8sctl",
+                "# Do not edit manually",
+                "",
+                "# Base image specifications are available at:",
+                "# https://github.com/qubernetes-dev/images/tree/main/cuda",
+                f"FROM {BASE_IMAGES['gpu']}",
+                "",
+                "LABEL org.opencontainers.image.created=2024-01-01T00:00:00",
+                f"LABEL org.opencontainers.image.title={project.name}",
+                "",
+                f"WORKDIR {WORKSPACE}",
+                "COPY requirements.txt .",
+                "RUN pip install --no-cache -r requirements.txt",
+            ],
+        )
+
+    @unittest.mock.patch("q8s.project.get_git_info")
+    @unittest.mock.patch("q8s.project.load")
+    def test_create_bakefile_no_repo(self, mock_load: Mock, mock_get_git_info: Mock):
+        mock_load.return_value = mocked_configuration
+        mock_get_git_info.return_value = GitInfo(
+            commit=None,
+            branch=None,
+            remote_url=None,
+            extra={},
+        )
+
+        project = Project("tests/fixtures/cache")
+
+        bakefile = StringIO()
+        project._Project___create_bakefile(bakefile)
+
+        bakefile_data = json.loads(bakefile.getvalue())
+
+        self.assertEqual(bakefile_data["group"]["default"]["targets"], ["cpu", "gpu"])
+        self.assertEqual(
+            bakefile_data["target"]["cpu"],
+            {
+                "context": "./cpu",
+                "dockerfile": "Dockerfile",
+                "tags": ["vstirbu/q8s-example:cpu"],
+                "platforms": ["linux/amd64"],
+            },
+        )
+        self.assertEqual(
+            bakefile_data["target"]["gpu"],
+            {
+                "context": "./gpu",
+                "dockerfile": "Dockerfile",
+                "tags": ["vstirbu/q8s-example:gpu"],
+                "platforms": ["linux/amd64"],
+            },
+        )
+
+    @unittest.mock.patch("q8s.project.get_git_info")
+    @unittest.mock.patch("q8s.project.load")
+    def test_create_bakefile_in_repo(self, mock_load: Mock, mock_get_git_info: Mock):
+        mock_load.return_value = mocked_configuration
+        mock_get_git_info.return_value = GitInfo(
+            commit="abc123",
+            branch="main",
+            remote_url="https://example.com/repo.git",
+            extra={},
+        )
+
+        project = Project("tests/fixtures/cache")
+
+        bakefile = StringIO()
+        project._Project___create_bakefile(bakefile)
+
+        bakefile_data = json.loads(bakefile.getvalue())
+
+        self.assertEqual(bakefile_data["group"]["default"]["targets"], ["cpu", "gpu"])
+        self.assertEqual(
+            bakefile_data["target"]["cpu"],
+            {
+                "context": "./cpu",
+                "dockerfile": "Dockerfile",
+                "tags": ["vstirbu/q8s-example:cpu-main"],
+                "platforms": ["linux/amd64"],
+            },
+        )
+        self.assertEqual(
+            bakefile_data["target"]["gpu"],
+            {
+                "context": "./gpu",
+                "dockerfile": "Dockerfile",
+                "tags": ["vstirbu/q8s-example:gpu-main"],
+                "platforms": ["linux/amd64"],
+            },
+        )
+
     @unittest.mock.patch("q8s.project.get_git_info")
     @unittest.mock.patch("q8s.project.sys.platform", "win32")
     @unittest.mock.patch("q8s.project.Popen")
